Module function

Module function 

Traits

Function
Trait for custom functions that can be called from formulas.

Functions

build_function_id
Builds a function identifier from name and number of arguments.